@@ -57,11 +57,15 @@ async def post_root(self, request):
     resp_list = []
 
     if self.batching:
-        resp_list = add_issues_format_insensitive_batch(self, els, self.debug, verbose=self.verbose)
+        resp_list = add_issues_format_insensitive_batch(
+            self, els, self.debug, verbose=self.verbose
+        )
         return response.json(resp_list)
 
     for el in els:
-        el = add_issues_format_insensitive(self, el, self.validator, debug=self.debug, verbose=self.verbose)
+        el = add_issues_format_insensitive(
+            self, el, self.validator, debug=self.debug, verbose=self.verbose
+        )
         resp_list.append(el)
     return response.json(resp_list)
 
@@ -88,16 +92,19 @@ async def add_start_time(request):
     request["start_time"] = time.time()
 
 
-async def add_perf_stats(request, response):
+async def add_perf_stats(self, request, response):
     """
     Prepend initial time when this request was served.
     Log the access long on each request.
     Log num of segments, sentences, words in payload.
     Log sentence and word speed.
     """
-    if request.path not in ['/ready', '/healthy']:
+    is_get = request.method.lower() == "get"
+    is_check = request.path in ["/ready", "/healthy"]
+    should_log = not (is_get or is_check)
+    if should_log:
         latency = round((time.time() - request["start_time"]) * 1000)
-        n_seg, n_sent, n_word = get_payload_stats(request.json)
+        n_seg, n_sent, n_word = get_payload_stats(request.json, self.validator.nlp)
         latency_sec = latency / 1000
 
         try:
@@ -198,13 +205,18 @@ class QRest(QRemoteConnection):
         self.ignore_html = ignore_html
         self.ignore_inside_quotes = ignore_inside_quotes
         nlp_obj = getattr(analyzer, "nlp", None)
-        self.validator = Validator(nlp_obj=nlp_obj, sentence_token_limit=sentence_token_limit, ignore_html=ignore_html)
+        self.validator = Validator(
+            nlp_obj=nlp_obj,
+            sentence_token_limit=sentence_token_limit,
+            ignore_html=ignore_html,
+        )
 
         self.app = Sanic(__name__)
 
         # Add the request and response middleware
         self.app.request_middleware.append(add_start_time)
-        self.app.response_middleware.append(add_perf_stats)
+        unary_add_perf_stats = partial(add_perf_stats, self)
+        self.app.response_middleware.append(unary_add_perf_stats)
 
         # Add routes
         # This works, but it is better to make these after instantiating the class
